[![PyPI](https://img.shields.io/pypi/v/hydra-colorlog)](https://pypi.org/project/hydra-colorlog/)
![PyPI - License](https://img.shields.io/pypi/l/hydra-colorlog)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hydra-colorlog)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/hydra-colorlog.svg)](https://pypistats.org/packages/hydra-colorlog)


# Hydra colorlog
See [website](https://cli.dev/docs/plugins/colorlog) for more information
